@@ -23,27 +23,35 @@ from mypy_boto3_es.paginator import (
     ListElasticsearchVersionsPaginator,
 )
 from mypy_boto3_es.type_defs import (
+    AcceptInboundCrossClusterSearchConnectionResponseTypeDef,
     AdvancedSecurityOptionsInputTypeDef,
     AssociatePackageResponseTypeDef,
     CancelElasticsearchServiceSoftwareUpdateResponseTypeDef,
     CognitoOptionsTypeDef,
     CreateElasticsearchDomainResponseTypeDef,
+    CreateOutboundCrossClusterSearchConnectionResponseTypeDef,
     CreatePackageResponseTypeDef,
     DeleteElasticsearchDomainResponseTypeDef,
+    DeleteInboundCrossClusterSearchConnectionResponseTypeDef,
+    DeleteOutboundCrossClusterSearchConnectionResponseTypeDef,
     DeletePackageResponseTypeDef,
     DescribeElasticsearchDomainConfigResponseTypeDef,
     DescribeElasticsearchDomainResponseTypeDef,
     DescribeElasticsearchDomainsResponseTypeDef,
     DescribeElasticsearchInstanceTypeLimitsResponseTypeDef,
+    DescribeInboundCrossClusterSearchConnectionsResponseTypeDef,
+    DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef,
     DescribePackagesFilterTypeDef,
     DescribePackagesResponseTypeDef,
     DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef,
     DescribeReservedElasticsearchInstancesResponseTypeDef,
     DissociatePackageResponseTypeDef,
     DomainEndpointOptionsTypeDef,
+    DomainInformationTypeDef,
     EBSOptionsTypeDef,
     ElasticsearchClusterConfigTypeDef,
     EncryptionAtRestOptionsTypeDef,
+    FilterTypeDef,
     GetCompatibleElasticsearchVersionsResponseTypeDef,
     GetUpgradeHistoryResponseTypeDef,
     GetUpgradeStatusResponseTypeDef,
@@ -57,6 +65,7 @@ from mypy_boto3_es.type_defs import (
     NodeToNodeEncryptionOptionsTypeDef,
     PackageSourceTypeDef,
     PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef,
+    RejectInboundCrossClusterSearchConnectionResponseTypeDef,
     SnapshotOptionsTypeDef,
     StartElasticsearchServiceSoftwareUpdateResponseTypeDef,
     TagTypeDef,
@@ -81,6 +90,7 @@ class Exceptions:
     ConflictException: Type[Boto3ClientError]
     DisabledOperationException: Type[Boto3ClientError]
     InternalException: Type[Boto3ClientError]
+    InvalidPaginationTokenException: Type[Boto3ClientError]
     InvalidTypeException: Type[Boto3ClientError]
     LimitExceededException: Type[Boto3ClientError]
     ResourceAlreadyExistsException: Type[Boto3ClientError]
@@ -90,55 +100,72 @@ class Exceptions:
 
 class ElasticsearchServiceClient:
     """
-    [ElasticsearchService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client)
+    [ElasticsearchService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client)
     """
 
     exceptions: Exceptions
 
-    def add_tags(self, ARN: str, TagList: List[TagTypeDef]) -> None:
+    def accept_inbound_cross_cluster_search_connection(
+        self, CrossClusterSearchConnectionId: str
+    ) -> AcceptInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Client.add_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.add_tags)
+        [Client.accept_inbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.accept_inbound_cross_cluster_search_connection)
+        """
+
+    def add_tags(self, ARN: str, TagList: List["TagTypeDef"]) -> None:
+        """
+        [Client.add_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.add_tags)
         """
 
     def associate_package(self, PackageID: str, DomainName: str) -> AssociatePackageResponseTypeDef:
         """
-        [Client.associate_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.associate_package)
+        [Client.associate_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.associate_package)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.can_paginate)
         """
 
     def cancel_elasticsearch_service_software_update(
         self, DomainName: str
     ) -> CancelElasticsearchServiceSoftwareUpdateResponseTypeDef:
         """
-        [Client.cancel_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
+        [Client.cancel_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
         """
 
     def create_elasticsearch_domain(
         self,
         DomainName: str,
         ElasticsearchVersion: str = None,
-        ElasticsearchClusterConfig: ElasticsearchClusterConfigTypeDef = None,
-        EBSOptions: EBSOptionsTypeDef = None,
+        ElasticsearchClusterConfig: "ElasticsearchClusterConfigTypeDef" = None,
+        EBSOptions: "EBSOptionsTypeDef" = None,
         AccessPolicies: str = None,
-        SnapshotOptions: SnapshotOptionsTypeDef = None,
+        SnapshotOptions: "SnapshotOptionsTypeDef" = None,
         VPCOptions: VPCOptionsTypeDef = None,
-        CognitoOptions: CognitoOptionsTypeDef = None,
-        EncryptionAtRestOptions: EncryptionAtRestOptionsTypeDef = None,
-        NodeToNodeEncryptionOptions: NodeToNodeEncryptionOptionsTypeDef = None,
+        CognitoOptions: "CognitoOptionsTypeDef" = None,
+        EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = None,
+        NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = None,
         AdvancedOptions: Dict[str, str] = None,
         LogPublishingOptions: Dict[
             Literal["INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS", "ES_APPLICATION_LOGS"],
-            LogPublishingOptionTypeDef,
+            "LogPublishingOptionTypeDef",
         ] = None,
-        DomainEndpointOptions: DomainEndpointOptionsTypeDef = None,
+        DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = None,
         AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = None,
     ) -> CreateElasticsearchDomainResponseTypeDef:
         """
-        [Client.create_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
+        [Client.create_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
+        """
+
+    def create_outbound_cross_cluster_search_connection(
+        self,
+        SourceDomainInfo: "DomainInformationTypeDef",
+        DestinationDomainInfo: "DomainInformationTypeDef",
+        ConnectionAlias: str,
+    ) -> CreateOutboundCrossClusterSearchConnectionResponseTypeDef:
+        """
+        [Client.create_outbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.create_outbound_cross_cluster_search_connection)
         """
 
     def create_package(
@@ -149,45 +176,59 @@ class ElasticsearchServiceClient:
         PackageDescription: str = None,
     ) -> CreatePackageResponseTypeDef:
         """
-        [Client.create_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.create_package)
+        [Client.create_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.create_package)
         """
 
     def delete_elasticsearch_domain(
         self, DomainName: str
     ) -> DeleteElasticsearchDomainResponseTypeDef:
         """
-        [Client.delete_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
+        [Client.delete_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
         """
 
     def delete_elasticsearch_service_role(self) -> None:
         """
-        [Client.delete_elasticsearch_service_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
+        [Client.delete_elasticsearch_service_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
+        """
+
+    def delete_inbound_cross_cluster_search_connection(
+        self, CrossClusterSearchConnectionId: str
+    ) -> DeleteInboundCrossClusterSearchConnectionResponseTypeDef:
+        """
+        [Client.delete_inbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.delete_inbound_cross_cluster_search_connection)
+        """
+
+    def delete_outbound_cross_cluster_search_connection(
+        self, CrossClusterSearchConnectionId: str
+    ) -> DeleteOutboundCrossClusterSearchConnectionResponseTypeDef:
+        """
+        [Client.delete_outbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.delete_outbound_cross_cluster_search_connection)
         """
 
     def delete_package(self, PackageID: str) -> DeletePackageResponseTypeDef:
         """
-        [Client.delete_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.delete_package)
+        [Client.delete_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.delete_package)
         """
 
     def describe_elasticsearch_domain(
         self, DomainName: str
     ) -> DescribeElasticsearchDomainResponseTypeDef:
         """
-        [Client.describe_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
+        [Client.describe_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
         """
 
     def describe_elasticsearch_domain_config(
         self, DomainName: str
     ) -> DescribeElasticsearchDomainConfigResponseTypeDef:
         """
-        [Client.describe_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
+        [Client.describe_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
         """
 
     def describe_elasticsearch_domains(
         self, DomainNames: List[str]
     ) -> DescribeElasticsearchDomainsResponseTypeDef:
         """
-        [Client.describe_elasticsearch_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
+        [Client.describe_elasticsearch_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
         """
 
     def describe_elasticsearch_instance_type_limits(
@@ -256,7 +297,21 @@ class ElasticsearchServiceClient:
         DomainName: str = None,
     ) -> DescribeElasticsearchInstanceTypeLimitsResponseTypeDef:
         """
-        [Client.describe_elasticsearch_instance_type_limits documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
+        [Client.describe_elasticsearch_instance_type_limits documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
+        """
+
+    def describe_inbound_cross_cluster_search_connections(
+        self, Filters: List[FilterTypeDef] = None, MaxResults: int = None, NextToken: str = None
+    ) -> DescribeInboundCrossClusterSearchConnectionsResponseTypeDef:
+        """
+        [Client.describe_inbound_cross_cluster_search_connections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_inbound_cross_cluster_search_connections)
+        """
+
+    def describe_outbound_cross_cluster_search_connections(
+        self, Filters: List[FilterTypeDef] = None, MaxResults: int = None, NextToken: str = None
+    ) -> DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef:
+        """
+        [Client.describe_outbound_cross_cluster_search_connections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_outbound_cross_cluster_search_connections)
         """
 
     def describe_packages(
@@ -266,7 +321,7 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribePackagesResponseTypeDef:
         """
-        [Client.describe_packages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.describe_packages)
+        [Client.describe_packages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_packages)
         """
 
     def describe_reserved_elasticsearch_instance_offerings(
@@ -276,7 +331,7 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef:
         """
-        [Client.describe_reserved_elasticsearch_instance_offerings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
+        [Client.describe_reserved_elasticsearch_instance_offerings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
         """
 
     def describe_reserved_elasticsearch_instances(
@@ -286,14 +341,14 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribeReservedElasticsearchInstancesResponseTypeDef:
         """
-        [Client.describe_reserved_elasticsearch_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
+        [Client.describe_reserved_elasticsearch_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
         """
 
     def dissociate_package(
         self, PackageID: str, DomainName: str
     ) -> DissociatePackageResponseTypeDef:
         """
-        [Client.dissociate_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
+        [Client.dissociate_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
         """
 
     def generate_presigned_url(
@@ -304,38 +359,38 @@ class ElasticsearchServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
         """
 
     def get_compatible_elasticsearch_versions(
         self, DomainName: str = None
     ) -> GetCompatibleElasticsearchVersionsResponseTypeDef:
         """
-        [Client.get_compatible_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
+        [Client.get_compatible_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
         """
 
     def get_upgrade_history(
         self, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> GetUpgradeHistoryResponseTypeDef:
         """
-        [Client.get_upgrade_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
+        [Client.get_upgrade_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
         """
 
     def get_upgrade_status(self, DomainName: str) -> GetUpgradeStatusResponseTypeDef:
         """
-        [Client.get_upgrade_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
+        [Client.get_upgrade_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
         """
 
     def list_domain_names(self) -> ListDomainNamesResponseTypeDef:
         """
-        [Client.list_domain_names documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
+        [Client.list_domain_names documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
         """
 
     def list_domains_for_package(
         self, PackageID: str, MaxResults: int = None, NextToken: str = None
     ) -> ListDomainsForPackageResponseTypeDef:
         """
-        [Client.list_domains_for_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
+        [Client.list_domains_for_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
         """
 
     def list_elasticsearch_instance_types(
@@ -346,26 +401,26 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> ListElasticsearchInstanceTypesResponseTypeDef:
         """
-        [Client.list_elasticsearch_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
+        [Client.list_elasticsearch_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
         """
 
     def list_elasticsearch_versions(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListElasticsearchVersionsResponseTypeDef:
         """
-        [Client.list_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
+        [Client.list_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
         """
 
     def list_packages_for_domain(
         self, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> ListPackagesForDomainResponseTypeDef:
         """
-        [Client.list_packages_for_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
+        [Client.list_packages_for_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
         """
 
     def list_tags(self, ARN: str) -> ListTagsResponseTypeDef:
         """
-        [Client.list_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.list_tags)
+        [Client.list_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.list_tags)
         """
 
     def purchase_reserved_elasticsearch_instance_offering(
@@ -375,47 +430,54 @@ class ElasticsearchServiceClient:
         InstanceCount: int = None,
     ) -> PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef:
         """
-        [Client.purchase_reserved_elasticsearch_instance_offering documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
+        [Client.purchase_reserved_elasticsearch_instance_offering documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
+        """
+
+    def reject_inbound_cross_cluster_search_connection(
+        self, CrossClusterSearchConnectionId: str
+    ) -> RejectInboundCrossClusterSearchConnectionResponseTypeDef:
+        """
+        [Client.reject_inbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.reject_inbound_cross_cluster_search_connection)
         """
 
     def remove_tags(self, ARN: str, TagKeys: List[str]) -> None:
         """
-        [Client.remove_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.remove_tags)
+        [Client.remove_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.remove_tags)
         """
 
     def start_elasticsearch_service_software_update(
         self, DomainName: str
     ) -> StartElasticsearchServiceSoftwareUpdateResponseTypeDef:
         """
-        [Client.start_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
+        [Client.start_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
         """
 
     def update_elasticsearch_domain_config(
         self,
         DomainName: str,
-        ElasticsearchClusterConfig: ElasticsearchClusterConfigTypeDef = None,
-        EBSOptions: EBSOptionsTypeDef = None,
-        SnapshotOptions: SnapshotOptionsTypeDef = None,
+        ElasticsearchClusterConfig: "ElasticsearchClusterConfigTypeDef" = None,
+        EBSOptions: "EBSOptionsTypeDef" = None,
+        SnapshotOptions: "SnapshotOptionsTypeDef" = None,
         VPCOptions: VPCOptionsTypeDef = None,
-        CognitoOptions: CognitoOptionsTypeDef = None,
+        CognitoOptions: "CognitoOptionsTypeDef" = None,
         AdvancedOptions: Dict[str, str] = None,
         AccessPolicies: str = None,
         LogPublishingOptions: Dict[
             Literal["INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS", "ES_APPLICATION_LOGS"],
-            LogPublishingOptionTypeDef,
+            "LogPublishingOptionTypeDef",
         ] = None,
-        DomainEndpointOptions: DomainEndpointOptionsTypeDef = None,
+        DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = None,
         AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = None,
     ) -> UpdateElasticsearchDomainConfigResponseTypeDef:
         """
-        [Client.update_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
+        [Client.update_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
         """
 
     def upgrade_elasticsearch_domain(
         self, DomainName: str, TargetVersion: str, PerformCheckOnly: bool = None
     ) -> UpgradeElasticsearchDomainResponseTypeDef:
         """
-        [Client.upgrade_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
+        [Client.upgrade_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
         """
 
     @overload
@@ -423,7 +485,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["describe_reserved_elasticsearch_instance_offerings"]
     ) -> DescribeReservedElasticsearchInstanceOfferingsPaginator:
         """
-        [Paginator.DescribeReservedElasticsearchInstanceOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
+        [Paginator.DescribeReservedElasticsearchInstanceOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
         """
 
     @overload
@@ -431,7 +493,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["describe_reserved_elasticsearch_instances"]
     ) -> DescribeReservedElasticsearchInstancesPaginator:
         """
-        [Paginator.DescribeReservedElasticsearchInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
+        [Paginator.DescribeReservedElasticsearchInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
         """
 
     @overload
@@ -439,7 +501,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["get_upgrade_history"]
     ) -> GetUpgradeHistoryPaginator:
         """
-        [Paginator.GetUpgradeHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
+        [Paginator.GetUpgradeHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
         """
 
     @overload
@@ -447,7 +509,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["list_elasticsearch_instance_types"]
     ) -> ListElasticsearchInstanceTypesPaginator:
         """
-        [Paginator.ListElasticsearchInstanceTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
+        [Paginator.ListElasticsearchInstanceTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
         """
 
     @overload
@@ -455,5 +517,5 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["list_elasticsearch_versions"]
     ) -> ListElasticsearchVersionsPaginator:
         """
-        [Paginator.ListElasticsearchVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.14/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
+        [Paginator.ListElasticsearchVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
         """
