@@ -3,9 +3,9 @@ Main interface for es service type definitions.
 
 Usage::
 
-    from mypy_boto3.es.type_defs import MasterUserOptionsTypeDef
+    from mypy_boto3.es.type_defs import AccessPoliciesStatusTypeDef
 
-    data: MasterUserOptionsTypeDef = {...}
+    data: AccessPoliciesStatusTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,105 +22,166 @@ else:
 
 
 __all__ = (
-    "MasterUserOptionsTypeDef",
-    "AdvancedSecurityOptionsInputTypeDef",
-    "ErrorDetailsTypeDef",
-    "DomainPackageDetailsTypeDef",
-    "AssociatePackageResponseTypeDef",
-    "ServiceSoftwareOptionsTypeDef",
-    "CancelElasticsearchServiceSoftwareUpdateResponseTypeDef",
-    "CognitoOptionsTypeDef",
-    "AdvancedSecurityOptionsTypeDef",
-    "DomainEndpointOptionsTypeDef",
-    "EBSOptionsTypeDef",
-    "ZoneAwarenessConfigTypeDef",
-    "ElasticsearchClusterConfigTypeDef",
-    "EncryptionAtRestOptionsTypeDef",
-    "LogPublishingOptionTypeDef",
-    "NodeToNodeEncryptionOptionsTypeDef",
-    "SnapshotOptionsTypeDef",
-    "VPCDerivedInfoTypeDef",
-    "ElasticsearchDomainStatusTypeDef",
-    "CreateElasticsearchDomainResponseTypeDef",
-    "PackageDetailsTypeDef",
-    "CreatePackageResponseTypeDef",
-    "DeleteElasticsearchDomainResponseTypeDef",
-    "DeletePackageResponseTypeDef",
-    "OptionStatusTypeDef",
     "AccessPoliciesStatusTypeDef",
+    "AdditionalLimitTypeDef",
     "AdvancedOptionsStatusTypeDef",
     "AdvancedSecurityOptionsStatusTypeDef",
+    "AdvancedSecurityOptionsTypeDef",
     "CognitoOptionsStatusTypeDef",
+    "CognitoOptionsTypeDef",
+    "CompatibleVersionsMapTypeDef",
     "DomainEndpointOptionsStatusTypeDef",
+    "DomainEndpointOptionsTypeDef",
+    "DomainInfoTypeDef",
+    "DomainInformationTypeDef",
+    "DomainPackageDetailsTypeDef",
     "EBSOptionsStatusTypeDef",
+    "EBSOptionsTypeDef",
     "ElasticsearchClusterConfigStatusTypeDef",
+    "ElasticsearchClusterConfigTypeDef",
+    "ElasticsearchDomainConfigTypeDef",
+    "ElasticsearchDomainStatusTypeDef",
     "ElasticsearchVersionStatusTypeDef",
     "EncryptionAtRestOptionsStatusTypeDef",
+    "EncryptionAtRestOptionsTypeDef",
+    "ErrorDetailsTypeDef",
+    "InboundCrossClusterSearchConnectionStatusTypeDef",
+    "InboundCrossClusterSearchConnectionTypeDef",
+    "InstanceCountLimitsTypeDef",
+    "InstanceLimitsTypeDef",
+    "LimitsTypeDef",
+    "LogPublishingOptionTypeDef",
     "LogPublishingOptionsStatusTypeDef",
+    "MasterUserOptionsTypeDef",
     "NodeToNodeEncryptionOptionsStatusTypeDef",
+    "NodeToNodeEncryptionOptionsTypeDef",
+    "OptionStatusTypeDef",
+    "OutboundCrossClusterSearchConnectionStatusTypeDef",
+    "OutboundCrossClusterSearchConnectionTypeDef",
+    "PackageDetailsTypeDef",
+    "RecurringChargeTypeDef",
+    "ReservedElasticsearchInstanceOfferingTypeDef",
+    "ReservedElasticsearchInstanceTypeDef",
+    "ServiceSoftwareOptionsTypeDef",
     "SnapshotOptionsStatusTypeDef",
+    "SnapshotOptionsTypeDef",
+    "StorageTypeLimitTypeDef",
+    "StorageTypeTypeDef",
+    "TagTypeDef",
+    "UpgradeHistoryTypeDef",
+    "UpgradeStepItemTypeDef",
     "VPCDerivedInfoStatusTypeDef",
-    "ElasticsearchDomainConfigTypeDef",
+    "VPCDerivedInfoTypeDef",
+    "ZoneAwarenessConfigTypeDef",
+    "AcceptInboundCrossClusterSearchConnectionResponseTypeDef",
+    "AdvancedSecurityOptionsInputTypeDef",
+    "AssociatePackageResponseTypeDef",
+    "CancelElasticsearchServiceSoftwareUpdateResponseTypeDef",
+    "CreateElasticsearchDomainResponseTypeDef",
+    "CreateOutboundCrossClusterSearchConnectionResponseTypeDef",
+    "CreatePackageResponseTypeDef",
+    "DeleteElasticsearchDomainResponseTypeDef",
+    "DeleteInboundCrossClusterSearchConnectionResponseTypeDef",
+    "DeleteOutboundCrossClusterSearchConnectionResponseTypeDef",
+    "DeletePackageResponseTypeDef",
     "DescribeElasticsearchDomainConfigResponseTypeDef",
     "DescribeElasticsearchDomainResponseTypeDef",
     "DescribeElasticsearchDomainsResponseTypeDef",
-    "AdditionalLimitTypeDef",
-    "InstanceCountLimitsTypeDef",
-    "InstanceLimitsTypeDef",
-    "StorageTypeLimitTypeDef",
-    "StorageTypeTypeDef",
-    "LimitsTypeDef",
     "DescribeElasticsearchInstanceTypeLimitsResponseTypeDef",
+    "DescribeInboundCrossClusterSearchConnectionsResponseTypeDef",
+    "DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef",
     "DescribePackagesFilterTypeDef",
     "DescribePackagesResponseTypeDef",
-    "RecurringChargeTypeDef",
-    "ReservedElasticsearchInstanceOfferingTypeDef",
     "DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef",
-    "ReservedElasticsearchInstanceTypeDef",
     "DescribeReservedElasticsearchInstancesResponseTypeDef",
     "DissociatePackageResponseTypeDef",
-    "CompatibleVersionsMapTypeDef",
+    "FilterTypeDef",
     "GetCompatibleElasticsearchVersionsResponseTypeDef",
-    "UpgradeStepItemTypeDef",
-    "UpgradeHistoryTypeDef",
     "GetUpgradeHistoryResponseTypeDef",
     "GetUpgradeStatusResponseTypeDef",
-    "DomainInfoTypeDef",
     "ListDomainNamesResponseTypeDef",
     "ListDomainsForPackageResponseTypeDef",
     "ListElasticsearchInstanceTypesResponseTypeDef",
     "ListElasticsearchVersionsResponseTypeDef",
     "ListPackagesForDomainResponseTypeDef",
-    "TagTypeDef",
     "ListTagsResponseTypeDef",
     "PackageSourceTypeDef",
     "PaginatorConfigTypeDef",
     "PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef",
+    "RejectInboundCrossClusterSearchConnectionResponseTypeDef",
     "StartElasticsearchServiceSoftwareUpdateResponseTypeDef",
     "UpdateElasticsearchDomainConfigResponseTypeDef",
     "UpgradeElasticsearchDomainResponseTypeDef",
     "VPCOptionsTypeDef",
 )
 
-MasterUserOptionsTypeDef = TypedDict(
-    "MasterUserOptionsTypeDef",
-    {"MasterUserARN": str, "MasterUserName": str, "MasterUserPassword": str},
+AccessPoliciesStatusTypeDef = TypedDict(
+    "AccessPoliciesStatusTypeDef", {"Options": str, "Status": "OptionStatusTypeDef"}
+)
+
+AdditionalLimitTypeDef = TypedDict(
+    "AdditionalLimitTypeDef", {"LimitName": str, "LimitValues": List[str]}, total=False
+)
+
+AdvancedOptionsStatusTypeDef = TypedDict(
+    "AdvancedOptionsStatusTypeDef", {"Options": Dict[str, str], "Status": "OptionStatusTypeDef"}
+)
+
+AdvancedSecurityOptionsStatusTypeDef = TypedDict(
+    "AdvancedSecurityOptionsStatusTypeDef",
+    {"Options": "AdvancedSecurityOptionsTypeDef", "Status": "OptionStatusTypeDef"},
+)
+
+AdvancedSecurityOptionsTypeDef = TypedDict(
+    "AdvancedSecurityOptionsTypeDef",
+    {"Enabled": bool, "InternalUserDatabaseEnabled": bool},
     total=False,
 )
 
-AdvancedSecurityOptionsInputTypeDef = TypedDict(
-    "AdvancedSecurityOptionsInputTypeDef",
+CognitoOptionsStatusTypeDef = TypedDict(
+    "CognitoOptionsStatusTypeDef",
+    {"Options": "CognitoOptionsTypeDef", "Status": "OptionStatusTypeDef"},
+)
+
+CognitoOptionsTypeDef = TypedDict(
+    "CognitoOptionsTypeDef",
+    {"Enabled": bool, "UserPoolId": str, "IdentityPoolId": str, "RoleArn": str},
+    total=False,
+)
+
+CompatibleVersionsMapTypeDef = TypedDict(
+    "CompatibleVersionsMapTypeDef", {"SourceVersion": str, "TargetVersions": List[str]}, total=False
+)
+
+DomainEndpointOptionsStatusTypeDef = TypedDict(
+    "DomainEndpointOptionsStatusTypeDef",
+    {"Options": "DomainEndpointOptionsTypeDef", "Status": "OptionStatusTypeDef"},
+)
+
+DomainEndpointOptionsTypeDef = TypedDict(
+    "DomainEndpointOptionsTypeDef",
     {
-        "Enabled": bool,
-        "InternalUserDatabaseEnabled": bool,
-        "MasterUserOptions": MasterUserOptionsTypeDef,
+        "EnforceHTTPS": bool,
+        "TLSSecurityPolicy": Literal["Policy-Min-TLS-1-0-2019-07", "Policy-Min-TLS-1-2-2019-07"],
     },
     total=False,
 )
 
-ErrorDetailsTypeDef = TypedDict(
-    "ErrorDetailsTypeDef", {"ErrorType": str, "ErrorMessage": str}, total=False
+DomainInfoTypeDef = TypedDict("DomainInfoTypeDef", {"DomainName": str}, total=False)
+
+_RequiredDomainInformationTypeDef = TypedDict(
+    "_RequiredDomainInformationTypeDef", {"DomainName": str}
 )
+_OptionalDomainInformationTypeDef = TypedDict(
+    "_OptionalDomainInformationTypeDef", {"OwnerId": str, "Region": str}, total=False
+)
+
+
+class DomainInformationTypeDef(
+    _RequiredDomainInformationTypeDef, _OptionalDomainInformationTypeDef
+):
+    pass
+
 
 DomainPackageDetailsTypeDef = TypedDict(
     "DomainPackageDetailsTypeDef",
@@ -134,59 +195,13 @@ DomainPackageDetailsTypeDef = TypedDict(
             "ASSOCIATING", "ASSOCIATION_FAILED", "ACTIVE", "DISSOCIATING", "DISSOCIATION_FAILED"
         ],
         "ReferencePath": str,
-        "ErrorDetails": ErrorDetailsTypeDef,
+        "ErrorDetails": "ErrorDetailsTypeDef",
     },
     total=False,
 )
 
-AssociatePackageResponseTypeDef = TypedDict(
-    "AssociatePackageResponseTypeDef",
-    {"DomainPackageDetails": DomainPackageDetailsTypeDef},
-    total=False,
-)
-
-ServiceSoftwareOptionsTypeDef = TypedDict(
-    "ServiceSoftwareOptionsTypeDef",
-    {
-        "CurrentVersion": str,
-        "NewVersion": str,
-        "UpdateAvailable": bool,
-        "Cancellable": bool,
-        "UpdateStatus": Literal[
-            "PENDING_UPDATE", "IN_PROGRESS", "COMPLETED", "NOT_ELIGIBLE", "ELIGIBLE"
-        ],
-        "Description": str,
-        "AutomatedUpdateDate": datetime,
-        "OptionalDeployment": bool,
-    },
-    total=False,
-)
-
-CancelElasticsearchServiceSoftwareUpdateResponseTypeDef = TypedDict(
-    "CancelElasticsearchServiceSoftwareUpdateResponseTypeDef",
-    {"ServiceSoftwareOptions": ServiceSoftwareOptionsTypeDef},
-    total=False,
-)
-
-CognitoOptionsTypeDef = TypedDict(
-    "CognitoOptionsTypeDef",
-    {"Enabled": bool, "UserPoolId": str, "IdentityPoolId": str, "RoleArn": str},
-    total=False,
-)
-
-AdvancedSecurityOptionsTypeDef = TypedDict(
-    "AdvancedSecurityOptionsTypeDef",
-    {"Enabled": bool, "InternalUserDatabaseEnabled": bool},
-    total=False,
-)
-
-DomainEndpointOptionsTypeDef = TypedDict(
-    "DomainEndpointOptionsTypeDef",
-    {
-        "EnforceHTTPS": bool,
-        "TLSSecurityPolicy": Literal["Policy-Min-TLS-1-0-2019-07", "Policy-Min-TLS-1-2-2019-07"],
-    },
-    total=False,
+EBSOptionsStatusTypeDef = TypedDict(
+    "EBSOptionsStatusTypeDef", {"Options": "EBSOptionsTypeDef", "Status": "OptionStatusTypeDef"}
 )
 
 EBSOptionsTypeDef = TypedDict(
@@ -200,8 +215,9 @@ EBSOptionsTypeDef = TypedDict(
     total=False,
 )
 
-ZoneAwarenessConfigTypeDef = TypedDict(
-    "ZoneAwarenessConfigTypeDef", {"AvailabilityZoneCount": int}, total=False
+ElasticsearchClusterConfigStatusTypeDef = TypedDict(
+    "ElasticsearchClusterConfigStatusTypeDef",
+    {"Options": "ElasticsearchClusterConfigTypeDef", "Status": "OptionStatusTypeDef"},
 )
 
 ElasticsearchClusterConfigTypeDef = TypedDict(
@@ -270,7 +286,7 @@ ElasticsearchClusterConfigTypeDef = TypedDict(
         "InstanceCount": int,
         "DedicatedMasterEnabled": bool,
         "ZoneAwarenessEnabled": bool,
-        "ZoneAwarenessConfig": ZoneAwarenessConfigTypeDef,
+        "ZoneAwarenessConfig": "ZoneAwarenessConfigTypeDef",
         "DedicatedMasterType": Literal[
             "m3.medium.elasticsearch",
             "m3.large.elasticsearch",
@@ -339,29 +355,22 @@ ElasticsearchClusterConfigTypeDef = TypedDict(
     total=False,
 )
 
-EncryptionAtRestOptionsTypeDef = TypedDict(
-    "EncryptionAtRestOptionsTypeDef", {"Enabled": bool, "KmsKeyId": str}, total=False
-)
-
-LogPublishingOptionTypeDef = TypedDict(
-    "LogPublishingOptionTypeDef", {"CloudWatchLogsLogGroupArn": str, "Enabled": bool}, total=False
-)
-
-NodeToNodeEncryptionOptionsTypeDef = TypedDict(
-    "NodeToNodeEncryptionOptionsTypeDef", {"Enabled": bool}, total=False
-)
-
-SnapshotOptionsTypeDef = TypedDict(
-    "SnapshotOptionsTypeDef", {"AutomatedSnapshotStartHour": int}, total=False
-)
-
-VPCDerivedInfoTypeDef = TypedDict(
-    "VPCDerivedInfoTypeDef",
+ElasticsearchDomainConfigTypeDef = TypedDict(
+    "ElasticsearchDomainConfigTypeDef",
     {
-        "VPCId": str,
-        "SubnetIds": List[str],
-        "AvailabilityZones": List[str],
-        "SecurityGroupIds": List[str],
+        "ElasticsearchVersion": "ElasticsearchVersionStatusTypeDef",
+        "ElasticsearchClusterConfig": "ElasticsearchClusterConfigStatusTypeDef",
+        "EBSOptions": "EBSOptionsStatusTypeDef",
+        "AccessPolicies": "AccessPoliciesStatusTypeDef",
+        "SnapshotOptions": "SnapshotOptionsStatusTypeDef",
+        "VPCOptions": "VPCDerivedInfoStatusTypeDef",
+        "CognitoOptions": "CognitoOptionsStatusTypeDef",
+        "EncryptionAtRestOptions": "EncryptionAtRestOptionsStatusTypeDef",
+        "NodeToNodeEncryptionOptions": "NodeToNodeEncryptionOptionsStatusTypeDef",
+        "AdvancedOptions": "AdvancedOptionsStatusTypeDef",
+        "LogPublishingOptions": "LogPublishingOptionsStatusTypeDef",
+        "DomainEndpointOptions": "DomainEndpointOptionsStatusTypeDef",
+        "AdvancedSecurityOptions": "AdvancedSecurityOptionsStatusTypeDef",
     },
     total=False,
 )
@@ -372,7 +381,7 @@ _RequiredElasticsearchDomainStatusTypeDef = TypedDict(
         "DomainId": str,
         "DomainName": str,
         "ARN": str,
-        "ElasticsearchClusterConfig": ElasticsearchClusterConfigTypeDef,
+        "ElasticsearchClusterConfig": "ElasticsearchClusterConfigTypeDef",
     },
 )
 _OptionalElasticsearchDomainStatusTypeDef = TypedDict(
@@ -385,21 +394,21 @@ _OptionalElasticsearchDomainStatusTypeDef = TypedDict(
         "Processing": bool,
         "UpgradeProcessing": bool,
         "ElasticsearchVersion": str,
-        "EBSOptions": EBSOptionsTypeDef,
+        "EBSOptions": "EBSOptionsTypeDef",
         "AccessPolicies": str,
-        "SnapshotOptions": SnapshotOptionsTypeDef,
-        "VPCOptions": VPCDerivedInfoTypeDef,
-        "CognitoOptions": CognitoOptionsTypeDef,
-        "EncryptionAtRestOptions": EncryptionAtRestOptionsTypeDef,
-        "NodeToNodeEncryptionOptions": NodeToNodeEncryptionOptionsTypeDef,
+        "SnapshotOptions": "SnapshotOptionsTypeDef",
+        "VPCOptions": "VPCDerivedInfoTypeDef",
+        "CognitoOptions": "CognitoOptionsTypeDef",
+        "EncryptionAtRestOptions": "EncryptionAtRestOptionsTypeDef",
+        "NodeToNodeEncryptionOptions": "NodeToNodeEncryptionOptionsTypeDef",
         "AdvancedOptions": Dict[str, str],
         "LogPublishingOptions": Dict[
             Literal["INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS", "ES_APPLICATION_LOGS"],
-            LogPublishingOptionTypeDef,
+            "LogPublishingOptionTypeDef",
         ],
-        "ServiceSoftwareOptions": ServiceSoftwareOptionsTypeDef,
-        "DomainEndpointOptions": DomainEndpointOptionsTypeDef,
-        "AdvancedSecurityOptions": AdvancedSecurityOptionsTypeDef,
+        "ServiceSoftwareOptions": "ServiceSoftwareOptionsTypeDef",
+        "DomainEndpointOptions": "DomainEndpointOptionsTypeDef",
+        "AdvancedSecurityOptions": "AdvancedSecurityOptionsTypeDef",
     },
     total=False,
 )
@@ -411,9 +420,140 @@ class ElasticsearchDomainStatusTypeDef(
     pass
 
 
-CreateElasticsearchDomainResponseTypeDef = TypedDict(
-    "CreateElasticsearchDomainResponseTypeDef",
-    {"DomainStatus": ElasticsearchDomainStatusTypeDef},
+ElasticsearchVersionStatusTypeDef = TypedDict(
+    "ElasticsearchVersionStatusTypeDef", {"Options": str, "Status": "OptionStatusTypeDef"}
+)
+
+EncryptionAtRestOptionsStatusTypeDef = TypedDict(
+    "EncryptionAtRestOptionsStatusTypeDef",
+    {"Options": "EncryptionAtRestOptionsTypeDef", "Status": "OptionStatusTypeDef"},
+)
+
+EncryptionAtRestOptionsTypeDef = TypedDict(
+    "EncryptionAtRestOptionsTypeDef", {"Enabled": bool, "KmsKeyId": str}, total=False
+)
+
+ErrorDetailsTypeDef = TypedDict(
+    "ErrorDetailsTypeDef", {"ErrorType": str, "ErrorMessage": str}, total=False
+)
+
+InboundCrossClusterSearchConnectionStatusTypeDef = TypedDict(
+    "InboundCrossClusterSearchConnectionStatusTypeDef",
+    {
+        "StatusCode": Literal[
+            "PENDING_ACCEPTANCE", "APPROVED", "REJECTING", "REJECTED", "DELETING", "DELETED"
+        ],
+        "Message": str,
+    },
+    total=False,
+)
+
+InboundCrossClusterSearchConnectionTypeDef = TypedDict(
+    "InboundCrossClusterSearchConnectionTypeDef",
+    {
+        "SourceDomainInfo": "DomainInformationTypeDef",
+        "DestinationDomainInfo": "DomainInformationTypeDef",
+        "CrossClusterSearchConnectionId": str,
+        "ConnectionStatus": "InboundCrossClusterSearchConnectionStatusTypeDef",
+    },
+    total=False,
+)
+
+InstanceCountLimitsTypeDef = TypedDict(
+    "InstanceCountLimitsTypeDef",
+    {"MinimumInstanceCount": int, "MaximumInstanceCount": int},
+    total=False,
+)
+
+InstanceLimitsTypeDef = TypedDict(
+    "InstanceLimitsTypeDef", {"InstanceCountLimits": "InstanceCountLimitsTypeDef"}, total=False
+)
+
+LimitsTypeDef = TypedDict(
+    "LimitsTypeDef",
+    {
+        "StorageTypes": List["StorageTypeTypeDef"],
+        "InstanceLimits": "InstanceLimitsTypeDef",
+        "AdditionalLimits": List["AdditionalLimitTypeDef"],
+    },
+    total=False,
+)
+
+LogPublishingOptionTypeDef = TypedDict(
+    "LogPublishingOptionTypeDef", {"CloudWatchLogsLogGroupArn": str, "Enabled": bool}, total=False
+)
+
+LogPublishingOptionsStatusTypeDef = TypedDict(
+    "LogPublishingOptionsStatusTypeDef",
+    {
+        "Options": Dict[
+            Literal["INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS", "ES_APPLICATION_LOGS"],
+            "LogPublishingOptionTypeDef",
+        ],
+        "Status": "OptionStatusTypeDef",
+    },
+    total=False,
+)
+
+MasterUserOptionsTypeDef = TypedDict(
+    "MasterUserOptionsTypeDef",
+    {"MasterUserARN": str, "MasterUserName": str, "MasterUserPassword": str},
+    total=False,
+)
+
+NodeToNodeEncryptionOptionsStatusTypeDef = TypedDict(
+    "NodeToNodeEncryptionOptionsStatusTypeDef",
+    {"Options": "NodeToNodeEncryptionOptionsTypeDef", "Status": "OptionStatusTypeDef"},
+)
+
+NodeToNodeEncryptionOptionsTypeDef = TypedDict(
+    "NodeToNodeEncryptionOptionsTypeDef", {"Enabled": bool}, total=False
+)
+
+_RequiredOptionStatusTypeDef = TypedDict(
+    "_RequiredOptionStatusTypeDef",
+    {
+        "CreationDate": datetime,
+        "UpdateDate": datetime,
+        "State": Literal["RequiresIndexDocuments", "Processing", "Active"],
+    },
+)
+_OptionalOptionStatusTypeDef = TypedDict(
+    "_OptionalOptionStatusTypeDef", {"UpdateVersion": int, "PendingDeletion": bool}, total=False
+)
+
+
+class OptionStatusTypeDef(_RequiredOptionStatusTypeDef, _OptionalOptionStatusTypeDef):
+    pass
+
+
+OutboundCrossClusterSearchConnectionStatusTypeDef = TypedDict(
+    "OutboundCrossClusterSearchConnectionStatusTypeDef",
+    {
+        "StatusCode": Literal[
+            "PENDING_ACCEPTANCE",
+            "VALIDATING",
+            "VALIDATION_FAILED",
+            "PROVISIONING",
+            "ACTIVE",
+            "REJECTED",
+            "DELETING",
+            "DELETED",
+        ],
+        "Message": str,
+    },
+    total=False,
+)
+
+OutboundCrossClusterSearchConnectionTypeDef = TypedDict(
+    "OutboundCrossClusterSearchConnectionTypeDef",
+    {
+        "SourceDomainInfo": "DomainInformationTypeDef",
+        "DestinationDomainInfo": "DomainInformationTypeDef",
+        "CrossClusterSearchConnectionId": str,
+        "ConnectionAlias": str,
+        "ConnectionStatus": "OutboundCrossClusterSearchConnectionStatusTypeDef",
+    },
     total=False,
 )
 
@@ -435,198 +575,11 @@ PackageDetailsTypeDef = TypedDict(
             "DELETE_FAILED",
         ],
         "CreatedAt": datetime,
-        "ErrorDetails": ErrorDetailsTypeDef,
+        "ErrorDetails": "ErrorDetailsTypeDef",
     },
     total=False,
 )
 
-CreatePackageResponseTypeDef = TypedDict(
-    "CreatePackageResponseTypeDef", {"PackageDetails": PackageDetailsTypeDef}, total=False
-)
-
-DeleteElasticsearchDomainResponseTypeDef = TypedDict(
-    "DeleteElasticsearchDomainResponseTypeDef",
-    {"DomainStatus": ElasticsearchDomainStatusTypeDef},
-    total=False,
-)
-
-DeletePackageResponseTypeDef = TypedDict(
-    "DeletePackageResponseTypeDef", {"PackageDetails": PackageDetailsTypeDef}, total=False
-)
-
-_RequiredOptionStatusTypeDef = TypedDict(
-    "_RequiredOptionStatusTypeDef",
-    {
-        "CreationDate": datetime,
-        "UpdateDate": datetime,
-        "State": Literal["RequiresIndexDocuments", "Processing", "Active"],
-    },
-)
-_OptionalOptionStatusTypeDef = TypedDict(
-    "_OptionalOptionStatusTypeDef", {"UpdateVersion": int, "PendingDeletion": bool}, total=False
-)
-
-
-class OptionStatusTypeDef(_RequiredOptionStatusTypeDef, _OptionalOptionStatusTypeDef):
-    pass
-
-
-AccessPoliciesStatusTypeDef = TypedDict(
-    "AccessPoliciesStatusTypeDef", {"Options": str, "Status": OptionStatusTypeDef}
-)
-
-AdvancedOptionsStatusTypeDef = TypedDict(
-    "AdvancedOptionsStatusTypeDef", {"Options": Dict[str, str], "Status": OptionStatusTypeDef}
-)
-
-AdvancedSecurityOptionsStatusTypeDef = TypedDict(
-    "AdvancedSecurityOptionsStatusTypeDef",
-    {"Options": AdvancedSecurityOptionsTypeDef, "Status": OptionStatusTypeDef},
-)
-
-CognitoOptionsStatusTypeDef = TypedDict(
-    "CognitoOptionsStatusTypeDef", {"Options": CognitoOptionsTypeDef, "Status": OptionStatusTypeDef}
-)
-
-DomainEndpointOptionsStatusTypeDef = TypedDict(
-    "DomainEndpointOptionsStatusTypeDef",
-    {"Options": DomainEndpointOptionsTypeDef, "Status": OptionStatusTypeDef},
-)
-
-EBSOptionsStatusTypeDef = TypedDict(
-    "EBSOptionsStatusTypeDef", {"Options": EBSOptionsTypeDef, "Status": OptionStatusTypeDef}
-)
-
-ElasticsearchClusterConfigStatusTypeDef = TypedDict(
-    "ElasticsearchClusterConfigStatusTypeDef",
-    {"Options": ElasticsearchClusterConfigTypeDef, "Status": OptionStatusTypeDef},
-)
-
-ElasticsearchVersionStatusTypeDef = TypedDict(
-    "ElasticsearchVersionStatusTypeDef", {"Options": str, "Status": OptionStatusTypeDef}
-)
-
-EncryptionAtRestOptionsStatusTypeDef = TypedDict(
-    "EncryptionAtRestOptionsStatusTypeDef",
-    {"Options": EncryptionAtRestOptionsTypeDef, "Status": OptionStatusTypeDef},
-)
-
-LogPublishingOptionsStatusTypeDef = TypedDict(
-    "LogPublishingOptionsStatusTypeDef",
-    {
-        "Options": Dict[
-            Literal["INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS", "ES_APPLICATION_LOGS"],
-            LogPublishingOptionTypeDef,
-        ],
-        "Status": OptionStatusTypeDef,
-    },
-    total=False,
-)
-
-NodeToNodeEncryptionOptionsStatusTypeDef = TypedDict(
-    "NodeToNodeEncryptionOptionsStatusTypeDef",
-    {"Options": NodeToNodeEncryptionOptionsTypeDef, "Status": OptionStatusTypeDef},
-)
-
-SnapshotOptionsStatusTypeDef = TypedDict(
-    "SnapshotOptionsStatusTypeDef",
-    {"Options": SnapshotOptionsTypeDef, "Status": OptionStatusTypeDef},
-)
-
-VPCDerivedInfoStatusTypeDef = TypedDict(
-    "VPCDerivedInfoStatusTypeDef", {"Options": VPCDerivedInfoTypeDef, "Status": OptionStatusTypeDef}
-)
-
-ElasticsearchDomainConfigTypeDef = TypedDict(
-    "ElasticsearchDomainConfigTypeDef",
-    {
-        "ElasticsearchVersion": ElasticsearchVersionStatusTypeDef,
-        "ElasticsearchClusterConfig": ElasticsearchClusterConfigStatusTypeDef,
-        "EBSOptions": EBSOptionsStatusTypeDef,
-        "AccessPolicies": AccessPoliciesStatusTypeDef,
-        "SnapshotOptions": SnapshotOptionsStatusTypeDef,
-        "VPCOptions": VPCDerivedInfoStatusTypeDef,
-        "CognitoOptions": CognitoOptionsStatusTypeDef,
-        "EncryptionAtRestOptions": EncryptionAtRestOptionsStatusTypeDef,
-        "NodeToNodeEncryptionOptions": NodeToNodeEncryptionOptionsStatusTypeDef,
-        "AdvancedOptions": AdvancedOptionsStatusTypeDef,
-        "LogPublishingOptions": LogPublishingOptionsStatusTypeDef,
-        "DomainEndpointOptions": DomainEndpointOptionsStatusTypeDef,
-        "AdvancedSecurityOptions": AdvancedSecurityOptionsStatusTypeDef,
-    },
-    total=False,
-)
-
-DescribeElasticsearchDomainConfigResponseTypeDef = TypedDict(
-    "DescribeElasticsearchDomainConfigResponseTypeDef",
-    {"DomainConfig": ElasticsearchDomainConfigTypeDef},
-)
-
-DescribeElasticsearchDomainResponseTypeDef = TypedDict(
-    "DescribeElasticsearchDomainResponseTypeDef", {"DomainStatus": ElasticsearchDomainStatusTypeDef}
-)
-
-DescribeElasticsearchDomainsResponseTypeDef = TypedDict(
-    "DescribeElasticsearchDomainsResponseTypeDef",
-    {"DomainStatusList": List[ElasticsearchDomainStatusTypeDef]},
-)
-
-AdditionalLimitTypeDef = TypedDict(
-    "AdditionalLimitTypeDef", {"LimitName": str, "LimitValues": List[str]}, total=False
-)
-
-InstanceCountLimitsTypeDef = TypedDict(
-    "InstanceCountLimitsTypeDef",
-    {"MinimumInstanceCount": int, "MaximumInstanceCount": int},
-    total=False,
-)
-
-InstanceLimitsTypeDef = TypedDict(
-    "InstanceLimitsTypeDef", {"InstanceCountLimits": InstanceCountLimitsTypeDef}, total=False
-)
-
-StorageTypeLimitTypeDef = TypedDict(
-    "StorageTypeLimitTypeDef", {"LimitName": str, "LimitValues": List[str]}, total=False
-)
-
-StorageTypeTypeDef = TypedDict(
-    "StorageTypeTypeDef",
-    {
-        "StorageTypeName": str,
-        "StorageSubTypeName": str,
-        "StorageTypeLimits": List[StorageTypeLimitTypeDef],
-    },
-    total=False,
-)
-
-LimitsTypeDef = TypedDict(
-    "LimitsTypeDef",
-    {
-        "StorageTypes": List[StorageTypeTypeDef],
-        "InstanceLimits": InstanceLimitsTypeDef,
-        "AdditionalLimits": List[AdditionalLimitTypeDef],
-    },
-    total=False,
-)
-
-DescribeElasticsearchInstanceTypeLimitsResponseTypeDef = TypedDict(
-    "DescribeElasticsearchInstanceTypeLimitsResponseTypeDef",
-    {"LimitsByRole": Dict[str, LimitsTypeDef]},
-    total=False,
-)
-
-DescribePackagesFilterTypeDef = TypedDict(
-    "DescribePackagesFilterTypeDef",
-    {"Name": Literal["PackageID", "PackageName", "PackageStatus"], "Value": List[str]},
-    total=False,
-)
-
-DescribePackagesResponseTypeDef = TypedDict(
-    "DescribePackagesResponseTypeDef",
-    {"PackageDetailsList": List[PackageDetailsTypeDef], "NextToken": str},
-    total=False,
-)
-
 RecurringChargeTypeDef = TypedDict(
     "RecurringChargeTypeDef",
     {"RecurringChargeAmount": float, "RecurringChargeFrequency": str},
@@ -702,18 +655,7 @@ ReservedElasticsearchInstanceOfferingTypeDef = TypedDict(
         "UsagePrice": float,
         "CurrencyCode": str,
         "PaymentOption": Literal["ALL_UPFRONT", "PARTIAL_UPFRONT", "NO_UPFRONT"],
-        "RecurringCharges": List[RecurringChargeTypeDef],
-    },
-    total=False,
-)
-
-DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef = TypedDict(
-    "DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef",
-    {
-        "NextToken": str,
-        "ReservedElasticsearchInstanceOfferings": List[
-            ReservedElasticsearchInstanceOfferingTypeDef
-        ],
+        "RecurringCharges": List["RecurringChargeTypeDef"],
     },
     total=False,
 )
@@ -792,33 +734,61 @@ ReservedElasticsearchInstanceTypeDef = TypedDict(
         "ElasticsearchInstanceCount": int,
         "State": str,
         "PaymentOption": Literal["ALL_UPFRONT", "PARTIAL_UPFRONT", "NO_UPFRONT"],
-        "RecurringCharges": List[RecurringChargeTypeDef],
+        "RecurringCharges": List["RecurringChargeTypeDef"],
     },
     total=False,
 )
 
-DescribeReservedElasticsearchInstancesResponseTypeDef = TypedDict(
-    "DescribeReservedElasticsearchInstancesResponseTypeDef",
+ServiceSoftwareOptionsTypeDef = TypedDict(
+    "ServiceSoftwareOptionsTypeDef",
     {
-        "NextToken": str,
-        "ReservedElasticsearchInstances": List[ReservedElasticsearchInstanceTypeDef],
+        "CurrentVersion": str,
+        "NewVersion": str,
+        "UpdateAvailable": bool,
+        "Cancellable": bool,
+        "UpdateStatus": Literal[
+            "PENDING_UPDATE", "IN_PROGRESS", "COMPLETED", "NOT_ELIGIBLE", "ELIGIBLE"
+        ],
+        "Description": str,
+        "AutomatedUpdateDate": datetime,
+        "OptionalDeployment": bool,
     },
     total=False,
 )
 
-DissociatePackageResponseTypeDef = TypedDict(
-    "DissociatePackageResponseTypeDef",
-    {"DomainPackageDetails": DomainPackageDetailsTypeDef},
+SnapshotOptionsStatusTypeDef = TypedDict(
+    "SnapshotOptionsStatusTypeDef",
+    {"Options": "SnapshotOptionsTypeDef", "Status": "OptionStatusTypeDef"},
+)
+
+SnapshotOptionsTypeDef = TypedDict(
+    "SnapshotOptionsTypeDef", {"AutomatedSnapshotStartHour": int}, total=False
+)
+
+StorageTypeLimitTypeDef = TypedDict(
+    "StorageTypeLimitTypeDef", {"LimitName": str, "LimitValues": List[str]}, total=False
+)
+
+StorageTypeTypeDef = TypedDict(
+    "StorageTypeTypeDef",
+    {
+        "StorageTypeName": str,
+        "StorageSubTypeName": str,
+        "StorageTypeLimits": List["StorageTypeLimitTypeDef"],
+    },
     total=False,
 )
 
-CompatibleVersionsMapTypeDef = TypedDict(
-    "CompatibleVersionsMapTypeDef", {"SourceVersion": str, "TargetVersions": List[str]}, total=False
-)
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
 
-GetCompatibleElasticsearchVersionsResponseTypeDef = TypedDict(
-    "GetCompatibleElasticsearchVersionsResponseTypeDef",
-    {"CompatibleElasticsearchVersions": List[CompatibleVersionsMapTypeDef]},
+UpgradeHistoryTypeDef = TypedDict(
+    "UpgradeHistoryTypeDef",
+    {
+        "UpgradeName": str,
+        "StartTimestamp": datetime,
+        "UpgradeStatus": Literal["IN_PROGRESS", "SUCCEEDED", "SUCCEEDED_WITH_ISSUES", "FAILED"],
+        "StepsList": List["UpgradeStepItemTypeDef"],
+    },
     total=False,
 )
 
@@ -833,20 +803,186 @@ UpgradeStepItemTypeDef = TypedDict(
     total=False,
 )
 
-UpgradeHistoryTypeDef = TypedDict(
-    "UpgradeHistoryTypeDef",
+VPCDerivedInfoStatusTypeDef = TypedDict(
+    "VPCDerivedInfoStatusTypeDef",
+    {"Options": "VPCDerivedInfoTypeDef", "Status": "OptionStatusTypeDef"},
+)
+
+VPCDerivedInfoTypeDef = TypedDict(
+    "VPCDerivedInfoTypeDef",
     {
-        "UpgradeName": str,
-        "StartTimestamp": datetime,
-        "UpgradeStatus": Literal["IN_PROGRESS", "SUCCEEDED", "SUCCEEDED_WITH_ISSUES", "FAILED"],
-        "StepsList": List[UpgradeStepItemTypeDef],
+        "VPCId": str,
+        "SubnetIds": List[str],
+        "AvailabilityZones": List[str],
+        "SecurityGroupIds": List[str],
     },
     total=False,
 )
 
+ZoneAwarenessConfigTypeDef = TypedDict(
+    "ZoneAwarenessConfigTypeDef", {"AvailabilityZoneCount": int}, total=False
+)
+
+AcceptInboundCrossClusterSearchConnectionResponseTypeDef = TypedDict(
+    "AcceptInboundCrossClusterSearchConnectionResponseTypeDef",
+    {"CrossClusterSearchConnection": "InboundCrossClusterSearchConnectionTypeDef"},
+    total=False,
+)
+
+AdvancedSecurityOptionsInputTypeDef = TypedDict(
+    "AdvancedSecurityOptionsInputTypeDef",
+    {
+        "Enabled": bool,
+        "InternalUserDatabaseEnabled": bool,
+        "MasterUserOptions": "MasterUserOptionsTypeDef",
+    },
+    total=False,
+)
+
+AssociatePackageResponseTypeDef = TypedDict(
+    "AssociatePackageResponseTypeDef",
+    {"DomainPackageDetails": "DomainPackageDetailsTypeDef"},
+    total=False,
+)
+
+CancelElasticsearchServiceSoftwareUpdateResponseTypeDef = TypedDict(
+    "CancelElasticsearchServiceSoftwareUpdateResponseTypeDef",
+    {"ServiceSoftwareOptions": "ServiceSoftwareOptionsTypeDef"},
+    total=False,
+)
+
+CreateElasticsearchDomainResponseTypeDef = TypedDict(
+    "CreateElasticsearchDomainResponseTypeDef",
+    {"DomainStatus": "ElasticsearchDomainStatusTypeDef"},
+    total=False,
+)
+
+CreateOutboundCrossClusterSearchConnectionResponseTypeDef = TypedDict(
+    "CreateOutboundCrossClusterSearchConnectionResponseTypeDef",
+    {
+        "SourceDomainInfo": "DomainInformationTypeDef",
+        "DestinationDomainInfo": "DomainInformationTypeDef",
+        "ConnectionAlias": str,
+        "ConnectionStatus": "OutboundCrossClusterSearchConnectionStatusTypeDef",
+        "CrossClusterSearchConnectionId": str,
+    },
+    total=False,
+)
+
+CreatePackageResponseTypeDef = TypedDict(
+    "CreatePackageResponseTypeDef", {"PackageDetails": "PackageDetailsTypeDef"}, total=False
+)
+
+DeleteElasticsearchDomainResponseTypeDef = TypedDict(
+    "DeleteElasticsearchDomainResponseTypeDef",
+    {"DomainStatus": "ElasticsearchDomainStatusTypeDef"},
+    total=False,
+)
+
+DeleteInboundCrossClusterSearchConnectionResponseTypeDef = TypedDict(
+    "DeleteInboundCrossClusterSearchConnectionResponseTypeDef",
+    {"CrossClusterSearchConnection": "InboundCrossClusterSearchConnectionTypeDef"},
+    total=False,
+)
+
+DeleteOutboundCrossClusterSearchConnectionResponseTypeDef = TypedDict(
+    "DeleteOutboundCrossClusterSearchConnectionResponseTypeDef",
+    {"CrossClusterSearchConnection": "OutboundCrossClusterSearchConnectionTypeDef"},
+    total=False,
+)
+
+DeletePackageResponseTypeDef = TypedDict(
+    "DeletePackageResponseTypeDef", {"PackageDetails": "PackageDetailsTypeDef"}, total=False
+)
+
+DescribeElasticsearchDomainConfigResponseTypeDef = TypedDict(
+    "DescribeElasticsearchDomainConfigResponseTypeDef",
+    {"DomainConfig": "ElasticsearchDomainConfigTypeDef"},
+)
+
+DescribeElasticsearchDomainResponseTypeDef = TypedDict(
+    "DescribeElasticsearchDomainResponseTypeDef",
+    {"DomainStatus": "ElasticsearchDomainStatusTypeDef"},
+)
+
+DescribeElasticsearchDomainsResponseTypeDef = TypedDict(
+    "DescribeElasticsearchDomainsResponseTypeDef",
+    {"DomainStatusList": List["ElasticsearchDomainStatusTypeDef"]},
+)
+
+DescribeElasticsearchInstanceTypeLimitsResponseTypeDef = TypedDict(
+    "DescribeElasticsearchInstanceTypeLimitsResponseTypeDef",
+    {"LimitsByRole": Dict[str, "LimitsTypeDef"]},
+    total=False,
+)
+
+DescribeInboundCrossClusterSearchConnectionsResponseTypeDef = TypedDict(
+    "DescribeInboundCrossClusterSearchConnectionsResponseTypeDef",
+    {
+        "CrossClusterSearchConnections": List["InboundCrossClusterSearchConnectionTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
+DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef = TypedDict(
+    "DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef",
+    {
+        "CrossClusterSearchConnections": List["OutboundCrossClusterSearchConnectionTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
+DescribePackagesFilterTypeDef = TypedDict(
+    "DescribePackagesFilterTypeDef",
+    {"Name": Literal["PackageID", "PackageName", "PackageStatus"], "Value": List[str]},
+    total=False,
+)
+
+DescribePackagesResponseTypeDef = TypedDict(
+    "DescribePackagesResponseTypeDef",
+    {"PackageDetailsList": List["PackageDetailsTypeDef"], "NextToken": str},
+    total=False,
+)
+
+DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef = TypedDict(
+    "DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef",
+    {
+        "NextToken": str,
+        "ReservedElasticsearchInstanceOfferings": List[
+            "ReservedElasticsearchInstanceOfferingTypeDef"
+        ],
+    },
+    total=False,
+)
+
+DescribeReservedElasticsearchInstancesResponseTypeDef = TypedDict(
+    "DescribeReservedElasticsearchInstancesResponseTypeDef",
+    {
+        "NextToken": str,
+        "ReservedElasticsearchInstances": List["ReservedElasticsearchInstanceTypeDef"],
+    },
+    total=False,
+)
+
+DissociatePackageResponseTypeDef = TypedDict(
+    "DissociatePackageResponseTypeDef",
+    {"DomainPackageDetails": "DomainPackageDetailsTypeDef"},
+    total=False,
+)
+
+FilterTypeDef = TypedDict("FilterTypeDef", {"Name": str, "Values": List[str]}, total=False)
+
+GetCompatibleElasticsearchVersionsResponseTypeDef = TypedDict(
+    "GetCompatibleElasticsearchVersionsResponseTypeDef",
+    {"CompatibleElasticsearchVersions": List["CompatibleVersionsMapTypeDef"]},
+    total=False,
+)
+
 GetUpgradeHistoryResponseTypeDef = TypedDict(
     "GetUpgradeHistoryResponseTypeDef",
-    {"UpgradeHistories": List[UpgradeHistoryTypeDef], "NextToken": str},
+    {"UpgradeHistories": List["UpgradeHistoryTypeDef"], "NextToken": str},
     total=False,
 )
 
@@ -860,15 +996,13 @@ GetUpgradeStatusResponseTypeDef = TypedDict(
     total=False,
 )
 
-DomainInfoTypeDef = TypedDict("DomainInfoTypeDef", {"DomainName": str}, total=False)
-
 ListDomainNamesResponseTypeDef = TypedDict(
-    "ListDomainNamesResponseTypeDef", {"DomainNames": List[DomainInfoTypeDef]}, total=False
+    "ListDomainNamesResponseTypeDef", {"DomainNames": List["DomainInfoTypeDef"]}, total=False
 )
 
 ListDomainsForPackageResponseTypeDef = TypedDict(
     "ListDomainsForPackageResponseTypeDef",
-    {"DomainPackageDetailsList": List[DomainPackageDetailsTypeDef], "NextToken": str},
+    {"DomainPackageDetailsList": List["DomainPackageDetailsTypeDef"], "NextToken": str},
     total=False,
 )
 
@@ -950,14 +1084,12 @@ ListElasticsearchVersionsResponseTypeDef = TypedDict(
 
 ListPackagesForDomainResponseTypeDef = TypedDict(
     "ListPackagesForDomainResponseTypeDef",
-    {"DomainPackageDetailsList": List[DomainPackageDetailsTypeDef], "NextToken": str},
+    {"DomainPackageDetailsList": List["DomainPackageDetailsTypeDef"], "NextToken": str},
     total=False,
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
-
 ListTagsResponseTypeDef = TypedDict(
-    "ListTagsResponseTypeDef", {"TagList": List[TagTypeDef]}, total=False
+    "ListTagsResponseTypeDef", {"TagList": List["TagTypeDef"]}, total=False
 )
 
 PackageSourceTypeDef = TypedDict(
@@ -974,15 +1106,21 @@ PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef = TypedDict(
     total=False,
 )
 
+RejectInboundCrossClusterSearchConnectionResponseTypeDef = TypedDict(
+    "RejectInboundCrossClusterSearchConnectionResponseTypeDef",
+    {"CrossClusterSearchConnection": "InboundCrossClusterSearchConnectionTypeDef"},
+    total=False,
+)
+
 StartElasticsearchServiceSoftwareUpdateResponseTypeDef = TypedDict(
     "StartElasticsearchServiceSoftwareUpdateResponseTypeDef",
-    {"ServiceSoftwareOptions": ServiceSoftwareOptionsTypeDef},
+    {"ServiceSoftwareOptions": "ServiceSoftwareOptionsTypeDef"},
     total=False,
 )
 
 UpdateElasticsearchDomainConfigResponseTypeDef = TypedDict(
     "UpdateElasticsearchDomainConfigResponseTypeDef",
-    {"DomainConfig": ElasticsearchDomainConfigTypeDef},
+    {"DomainConfig": "ElasticsearchDomainConfigTypeDef"},
 )
 
 UpgradeElasticsearchDomainResponseTypeDef = TypedDict(
